pub struct DigCollateralCoin { /* private fields */ }Implementations
Sourceimpl DigCollateralCoin
impl DigCollateralCoin
pub fn coin(&self) -> Coin
pub fn proof(&self) -> LineageProof
Sourcepub fn morph_store_launcher_id_for_collateral(
store_launcher_id: Bytes32,
) -> Bytes32
pub fn morph_store_launcher_id_for_collateral( store_launcher_id: Bytes32, ) -> Bytes32
Morphs a DIG store launcher ID into the DIG store collateral coin namespace.
Sourcepub fn morph_store_launcher_id_for_mirror(
store_launcher_id: Bytes32,
offset: &BigInt,
) -> Bytes32
pub fn morph_store_launcher_id_for_mirror( store_launcher_id: Bytes32, offset: &BigInt, ) -> Bytes32
Morphs a DIG store launcher ID into the DIG mirror collateral coin namespace.
Sourcepub async fn from_coin_state(
peer: &Peer,
coin_state: CoinState,
) -> Result<Self, WalletError>
pub async fn from_coin_state( peer: &Peer, coin_state: CoinState, ) -> Result<Self, WalletError>
Instantiates a $DIG collateral coin Verifies that coin is unspent and locked by the $DIG P2Parent puzzle
Sourcepub fn create_collateral(
dig_coins: Vec<DigCoin>,
amount: u64,
store_id: Bytes32,
synthetic_key: PublicKey,
fee_coins: Vec<Coin>,
fee: u64,
) -> Result<Vec<CoinSpend>, WalletError>
pub fn create_collateral( dig_coins: Vec<DigCoin>, amount: u64, store_id: Bytes32, synthetic_key: PublicKey, fee_coins: Vec<Coin>, fee: u64, ) -> Result<Vec<CoinSpend>, WalletError>
Uses the specified $DIG to create a collateral coin for the provided DIG store ID (launcher ID)
pub fn create_mirror( dig_coins: Vec<DigCoin>, amount: u64, store_id: Bytes32, mirror_urls: Vec<String>, epoch: BigInt, synthetic_key: PublicKey, fee_coins: Vec<Coin>, fee: u64, ) -> Result<Vec<CoinSpend>, WalletError>